@@ -28,19 +28,24 @@ from conans.util.tracer import (log_package_upload, log_recipe_upload,
 from conans.client.source import merge_directories
 from conans.util.env_reader import get_env
 from conans.search.search import filter_packages
+from conans.client.cmd.uploader import UPLOAD_POLICY_SKIP
+from conans.util import progress_bar
 
 
 class RemoteManager(object):
     """ Will handle the remotes to get recipes, packages etc """
 
-    def __init__(self, client_cache, auth_manager, output):
+    def __init__(self, client_cache, auth_manager, output, plugin_manager):
         self._client_cache = client_cache
         self._output = output
         self._auth_manager = auth_manager
+        self._plugin_manager = plugin_manager
 
-    def upload_recipe(self, conan_reference, remote, retry, retry_wait, ignore_deleted_file,
-                      skip_upload=False, no_overwrite=None):
-        """Will upload the conans to the first remote"""
+
+    def upload_recipe(self, conan_reference, remote, retry, retry_wait, policy, remote_manifest):
+        conanfile_path = self._client_cache.conanfile(conan_reference)
+        self._plugin_manager.execute("pre_upload_recipe", conanfile_path=conanfile_path,
+                                     reference=conan_reference, remote=remote)
         t1 = time.time()
         export_folder = self._client_cache.export(conan_reference)
 
@@ -58,11 +63,11 @@ class RemoteManager(object):
         src_files, src_symlinks = gather_files(export_src_folder)
         the_files = _compress_recipe_files(files, symlinks, src_files, src_symlinks, export_folder,
                                            self._output)
-        if skip_upload:
+        if policy == UPLOAD_POLICY_SKIP:
             return None
 
         ret, new_ref = self._call_remote(remote, "upload_recipe", conan_reference, the_files, retry,
-                                         retry_wait, ignore_deleted_file, no_overwrite)
+                                         retry_wait, policy, remote_manifest)
         duration = time.time() - t1
         log_recipe_upload(new_ref, duration, the_files, remote.name)
         if ret:
@@ -72,6 +77,8 @@ class RemoteManager(object):
         else:
             msg = "Recipe is up to date, upload skipped"
         self._output.info(msg)
+        self._plugin_manager.execute("post_upload_recipe", conanfile_path=conanfile_path,
+                                     reference=conan_reference, remote=remote)
         return new_ref
 
     def _package_integrity_check(self, package_reference, files, package_folder):
@@ -100,9 +107,14 @@ class RemoteManager(object):
             self._output.rewrite_line("Package integrity OK!")
         self._output.writeln("")
 
-    def upload_package(self, package_reference, remote, retry, retry_wait, skip_upload=False,
-                       integrity_check=False, no_overwrite=None):
+    def upload_package(self, package_reference, remote, retry, retry_wait,
+                       integrity_check=False, policy=None):
         """Will upload the package to the first remote"""
+        conanfile_path = self._client_cache.conanfile(package_reference.conan)
+        self._plugin_manager.execute("pre_upload_package", conanfile_path=conanfile_path,
+                                     reference=package_reference.conan,
+                                     package_id=package_reference.package_id,
+                                     remote=remote)
         t1 = time.time()
         # existing package, will use short paths if defined
         package_folder = self._client_cache.package(package_reference, short_paths=None)
@@ -132,11 +144,11 @@ class RemoteManager(object):
                          % (time.time() - t1))
 
         the_files = compress_package_files(files, symlinks, package_folder, self._output)
-        if skip_upload:
+        if policy == UPLOAD_POLICY_SKIP:
             return None
 
         tmp = self._call_remote(remote, "upload_package", package_reference, the_files,
-                                retry, retry_wait, no_overwrite)
+                                retry, retry_wait, policy)
         duration = time.time() - t1
         log_package_upload(package_reference, duration, the_files, remote)
         logger.debug("====> Time remote_manager upload_package: %f" % duration)
@@ -144,6 +156,9 @@ class RemoteManager(object):
             self._output.rewrite_line("Package is up to date, upload skipped")
             self._output.writeln("")
 
+        self._plugin_manager.execute("post_upload_package", conanfile_path=conanfile_path,
+                                     reference=package_reference.conan,
+                                     package_id=package_reference.package_id, remote=remote)
         return tmp
 
     def get_conan_manifest(self, conan_reference, remote):
@@ -176,6 +191,7 @@ class RemoteManager(object):
         Will iterate the remotes to find the conans unless remote was specified
 
         returns (dict relative_filepath:abs_path , remote_name)"""
+        self._plugin_manager.execute("pre_download_recipe", reference=conan_reference, remote=remote)
         dest_folder = self._client_cache.export(conan_reference)
         rmdir(dest_folder)
 
@@ -185,10 +201,13 @@ class RemoteManager(object):
         duration = time.time() - t1
         log_recipe_download(conan_reference, duration, remote.name, zipped_files)
 
-        unzip_and_get_files(zipped_files, dest_folder, EXPORT_TGZ_NAME)
+        unzip_and_get_files(zipped_files, dest_folder, EXPORT_TGZ_NAME, output=self._output)
         # Make sure that the source dir is deleted
         rm_conandir(self._client_cache.source(conan_reference))
         touch_folder(dest_folder)
+        conanfile_path = self._client_cache.conanfile(conan_reference)
+        self._plugin_manager.execute("post_download_recipe", conanfile_path=conanfile_path,
+                                     reference=conan_reference, remote=remote)
         return conan_reference
 
     def get_recipe_sources(self, conan_reference, export_folder, export_sources_folder, remote):
@@ -203,7 +222,8 @@ class RemoteManager(object):
         duration = time.time() - t1
         log_recipe_sources_download(conan_reference, duration, remote.name, zipped_files)
 
-        unzip_and_get_files(zipped_files, export_sources_folder, EXPORT_SOURCES_TGZ_NAME)
+        unzip_and_get_files(zipped_files, export_sources_folder, EXPORT_SOURCES_TGZ_NAME,
+                            output=self._output)
         c_src_path = os.path.join(export_sources_folder, EXPORT_SOURCES_DIR_OLD)
         if os.path.exists(c_src_path):
             merge_directories(c_src_path, export_sources_folder)
@@ -213,6 +233,10 @@ class RemoteManager(object):
 
     def get_package(self, package_reference, dest_folder, remote, output, recorder):
         package_id = package_reference.package_id
+        conanfile_path = self._client_cache.conanfile(package_reference.conan)
+        self._plugin_manager.execute("pre_download_package", conanfile_path=conanfile_path,
+                                     reference=package_reference.conan, package_id=package_id,
+                                     remote=remote)
         output.info("Retrieving package %s from remote '%s' " % (package_id, remote.name))
         rm_conandir(dest_folder)  # Remove first the destination folder
         t1 = time.time()
@@ -220,7 +244,7 @@ class RemoteManager(object):
             zipped_files = self._call_remote(remote, "get_package", package_reference, dest_folder)
             duration = time.time() - t1
             log_package_download(package_reference, duration, remote, zipped_files)
-            unzip_and_get_files(zipped_files, dest_folder, PACKAGE_TGZ_NAME)
+            unzip_and_get_files(zipped_files, dest_folder, PACKAGE_TGZ_NAME, output=self._output)
             # Issue #214 https://github.com/conan-io/conan/issues/214
             touch_folder(dest_folder)
             if get_env("CONAN_READ_ONLY_CACHE", False):
@@ -239,6 +263,9 @@ class RemoteManager(object):
                 raise ConanException("%s\n\nCouldn't remove folder '%s', might be busy or open. Close any app "
                                      "using it, and retry" % (str(e), dest_folder))
             raise
+        self._plugin_manager.execute("post_download_package", conanfile_path=conanfile_path,
+                                     reference=package_reference.conan, package_id=package_id,
+                                     remote=remote)
 
     def search_recipes(self, remote, pattern=None, ignorecase=True):
         """
@@ -298,7 +325,7 @@ def _compress_recipe_files(files, symlinks, src_files, src_symlinks, dest_folder
             result[tgz_name] = tgz_path
         elif tgz_files:
             output.rewrite_line(msg)
-            tgz_path = compress_files(tgz_files, tgz_symlinks, tgz_name, dest_folder)
+            tgz_path = compress_files(tgz_files, tgz_symlinks, tgz_name, dest_folder, output)
             result[tgz_name] = tgz_path
 
     add_tgz(EXPORT_TGZ_NAME, export_tgz_path, files, symlinks, "Compressing recipe...")
@@ -311,9 +338,9 @@ def _compress_recipe_files(files, symlinks, src_files, src_symlinks, dest_folder
 def compress_package_files(files, symlinks, dest_folder, output):
     tgz_path = files.get(PACKAGE_TGZ_NAME)
     if not tgz_path:
-        output.rewrite_line("Compressing package...")
+        output.writeln("Compressing package...")
         tgz_files = {f: path for f, path in files.items() if f not in [CONANINFO, CONAN_MANIFEST]}
-        tgz_path = compress_files(tgz_files, symlinks, PACKAGE_TGZ_NAME, dest_dir=dest_folder)
+        tgz_path = compress_files(tgz_files, symlinks, PACKAGE_TGZ_NAME, dest_folder, output)
 
     return {PACKAGE_TGZ_NAME: tgz_path,
             CONANINFO: files[CONANINFO],
@@ -330,7 +357,7 @@ def check_compressed_files(tgz_name, files):
                                  "Please upgrade conan client." % f)
 
 
-def compress_files(files, symlinks, name, dest_dir):
+def compress_files(files, symlinks, name, dest_dir, output=None):
     t1 = time.time()
     # FIXME, better write to disk sequentially and not keep tgz contents in memory
     tgz_path = os.path.join(dest_dir, name)
@@ -346,6 +373,11 @@ def compress_files(files, symlinks, name, dest_dir):
             tgz.addfile(tarinfo=info)
 
         mask = ~(stat.S_IWOTH | stat.S_IWGRP)
+        i_file = 0
+        n_files = len(files)
+        last_progress = None
+        if output and n_files > 1 and not output.is_terminal:
+            output.write("[")
         for filename, abs_path in sorted(files.items()):
             info = tarfile.TarInfo(name=filename)
             info.size = os.stat(abs_path).st_size
@@ -357,7 +389,22 @@ def compress_files(files, symlinks, name, dest_dir):
             else:
                 with open(abs_path, 'rb') as file_handler:
                     tgz.addfile(tarinfo=info, fileobj=file_handler)
+            if output and n_files > 1:
+                i_file = i_file + 1
+                units = min(50, int(50 * i_file / n_files))
+                if last_progress != units:  # Avoid screen refresh if nothing has change
+                    if output.is_terminal:
+                        text = "%s/%s files" % (i_file, n_files)
+                        output.rewrite_line("[%s%s] %s" % ('=' * units, ' ' * (50 - units), text))
+                    else:
+                        output.write('=' * (units - (last_progress or 0)))
+                    last_progress = units
 
+        if output and n_files > 1:
+            if output.is_terminal:
+                output.writeln("")
+            else:
+                output.writeln("]")
         tgz.close()
 
     clean_dirty(tgz_path)
@@ -367,21 +414,22 @@ def compress_files(files, symlinks, name, dest_dir):
     return tgz_path
 
 
-def unzip_and_get_files(files, destination_dir, tgz_name):
+def unzip_and_get_files(files, destination_dir, tgz_name, output):
     """Moves all files from package_files, {relative_name: tmp_abs_path}
     to destination_dir, unzipping the "tgz_name" if found"""
 
     tgz_file = files.pop(tgz_name, None)
     check_compressed_files(tgz_name, files)
     if tgz_file:
-        uncompress_file(tgz_file, destination_dir)
+        uncompress_file(tgz_file, destination_dir, output=output)
         os.remove(tgz_file)
 
 
-def uncompress_file(src_path, dest_folder):
+def uncompress_file(src_path, dest_folder, output):
     t1 = time.time()
     try:
-        with open(src_path, 'rb') as file_handler:
+        with progress_bar.open_binary(src_path, desc="Decompressing %s" % os.path.basename(src_path),
+                                      output=output) as file_handler:
             tar_extract(file_handler, dest_folder)
     except Exception as e:
         error_msg = "Error while downloading/extracting files to %s\n%s\n" % (dest_folder, str(e))
