@@ -1,7 +1,6 @@
 import os
 import sys
 from conans.client.output import ConanOutput
-from conans.model.username import Username
 from conans.errors import InvalidNameException, ConanException
 import getpass
 from six.moves import input as raw_input
@@ -40,15 +39,10 @@ class UserIO(object):
     def request_login(self, remote_name, username=None):
         """Request user to input their name and password
         :param username If username is specified it only request password"""
-        user_input = ''
-        while not username:
-            try:
-                if self._interactive:
-                    self.out.write("Remote '%s' username: " % remote_name)
-                user_input = self.get_username(remote_name)
-                username = Username(user_input)
-            except InvalidNameException:
-                self.out.error('%s is not a valid username' % user_input)
+        if self._interactive:
+            self.out.write("Remote '%s' username: " % remote_name)
+        username = self.get_username(remote_name)
+
         if self._interactive:
             self.out.write('Please enter a password for "%s" account: ' % username)
         try:
